@@ -5,24 +5,21 @@
 **
 ** Copyright (C) 2002-2004 Steve Lhomme.  All rights reserved.
 **
-** This file may be distributed under the terms of the Q Public License
-** as defined by Trolltech AS of Norway and appearing in the file
-** LICENSE.QPL included in the packaging of this file.
-**
-** This file may be distributed and/or modified under the terms of the
-** GNU General Public License version 2 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.
-**
-** Licensees holding an other license may use this file in accordance with 
-** the Agreement provided with the Software.
-**
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-**
-** See http://www.matroska.org/license/qpl/ for QPL licensing information.
-** See http://www.matroska.org/license/gpl/ for GPL licensing information.
+** This library is free software; you can redistribute it and/or
+** modify it under the terms of the GNU Lesser General Public
+** License as published by the Free Software Foundation; either
+** version 2.1 of the License, or (at your option) any later version.
+** 
+** This library is distributed in the hope that it will be useful,
+** but WITHOUT ANY WARRANTY; without even the implied warranty of
+** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+** Lesser General Public License for more details.
+** 
+** You should have received a copy of the GNU Lesser General Public
+** License along with this library; if not, write to the Free Software
+** Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 **
+** See http://www.matroska.org/license/lgpl/ for LGPL licensing information.**
 ** Contact license@matroska.org if any conditions of this licensing are
 ** not clear to you.
 **
@@ -30,7 +27,7 @@
 
 /*!
 	\file
-	\version \$Id: KaxCluster.cpp,v 1.7 2004/01/10 16:50:50 robux4 Exp $
+	\version \$Id: KaxCluster.cpp,v 1.9 2004/04/21 19:50:10 mosu Exp $
 	\author Steve Lhomme     <robux4 @ users.sf.net>
 */
 #include "matroska/KaxCluster.h"
@@ -42,18 +39,12 @@
 // sub elements
 START_LIBMATROSKA_NAMESPACE
 
-#if MATROSKA_VERSION == 1
-EbmlSemantic KaxCluster_ContextList[3] =
-#else // MATROSKA_VERSION
 EbmlSemantic KaxCluster_ContextList[4] =
-#endif // MATROSKA_VERSION
 {
 	EbmlSemantic(true,  true,  KaxClusterTimecode::ClassInfos),
 	EbmlSemantic(false, true,  KaxClusterPrevSize::ClassInfos),
 	EbmlSemantic(true,  false, KaxBlockGroup::ClassInfos),
-#if MATROSKA_VERSION >= 2
 	EbmlSemantic(false, true,  KaxClusterPosition::ClassInfos),
-#endif // MATROSKA_VERSION
 };
 
 const EbmlSemanticContext KaxCluster_Context = EbmlSemanticContext(countof(KaxCluster_ContextList), KaxCluster_ContextList, &KaxSegment_Context, *GetKaxGlobal_Context, &KaxCluster::ClassInfos);
